Package: Bios2cor
Type: Package
Title: From Biological Sequences and Simulations to Correlation
        Analysis
Version: 2.2.2
Date: 2024-10-15
Author: Bruck Taddese [aut],
  Antoine Garnier [aut],
  Madeline Deniaud [aut],
  Julien Pele [ctb],
  Lea Bellenger [ctb],
  Jean-Michel Becu [ctb],
  Marie Chabbert [aut, cre]
Authors@R: c(person(given = "Bruck",
                      family = "Taddese",
                      role = "aut"),
               person(given = "Antoine",
                      family = "Garnier",
                      role = "aut"),
               person(given = "Madeline",
                      family = "Deniaud",
                      role = "aut"),
               person(given = "Julien",
                      family = "Pele",
                      role = "ctb"),
               person(given = "Lea",
                      family = "Bellenger",
                      role = "ctb"),
               person(given = "Jean-Michel",
                      family = "Becu",
                      role = "ctb"),
               person(given = "Marie",
                      family = "Chabbert",
                      role = c("aut", "cre"),
                      email = "marie.chabbert@univ-angers.fr"))
Maintainer: Marie Chabbert <marie.chabbert@univ-angers.fr>
Depends: R (>= 3.5), bio3d, circular, bigmemory, parallel
Imports: igraph
Description: Utilities for computation and analysis of correlation/covariation in multiple sequence alignments and in side chain motions during molecular dynamics simulations. Features include the computation of correlation/covariation scores using a variety of scoring functions between either sequence positions in alignments or side chain dihedral angles in molecular dynamics simulations and utilities to analyze the correlation/covariation matrix through a variety of tools including network representation and principal components analysis. In addition, several utility functions are based on the R graphical environment to provide friendly tools for help in data interpretation. Examples of sequence covariation analysis are provided in: (1) Pele J, Moreau M, Abdi H, Rodien P, Castel H, Chabbert M (2014) <doi:10.1002/prot.24570> and (2) Taddese B, Deniaud M, Garnier A, Tiss A, Guissouma H, Abdi H, Henrion D, Chabbert M (2018) <doi:10.1371/journal.pcbi.1006209>. An example of side chain correlated motion analysis is provided in: Taddese B, Garnier A, Abdi H, Henrion D, Chabbert M (2020) <doi:10.1038/s41598-020-72766-1>. This work was supported by the French National Research Agency (Grant number: ANR-11-BSV2-026) and by GENCI (Grant number: 100567).
License: GPL (>= 2)
NeedsCompilation: no
Packaged: 2024-11-13 18:29:12 UTC; root
Repository: CRAN
Date/Publication: 2024-11-14 13:40:23 UTC
Built: R 4.6.0; ; 2026-04-27 15:05:40 UTC; unix
