export("angles.plot", "angle2rotamer", "centered_pca", "top_pairs_analysis", "scores.boxplot", "write.scores", "write.entropy", "network.plot", "write.pca", "pca_screeplot", "delta_filter", "dynamic_structure", "elsc", "entropy", "scores_entropy.plot", "import.fasta", "import.msf", "mcbasc", "mi","mip", "omes", "pca_2d", "random.msa", "dynamic_circular", "dynamic_mi", "dynamic_mip", "dynamic_omes", "dynamic_entropy", "write.pca.pdb", "xyz2torsion")

import("bio3d", "bigmemory", "parallel")

importFrom("circular", "circular", "cor.circular")

importFrom("igraph", "graph_from_data_frame", "degree")

importFrom("grDevices", "adjustcolor", "dev.off", "graphics.off","pdf", "png", "rgb")
importFrom("graphics", "abline", "box", "boxplot", "layout", "lines", "par", "plot", "points","hist")
importFrom("stats", "sd", "var","na.omit")
importFrom("utils", "read.table", "setTxtProgressBar", "txtProgressBar", "write.table","write.csv")
